@@ -228,7 +228,7 @@ def get_dataset_name(db, file_name):
     return res
 
 
-def upload_csv(args):
+def upload_csv(file_name, project_id, tag):
     # headers = {
     #     'Content-Type': 'multipart/form-data; boundary=----WebKitFormBoundary0W2raMzzSKutrSDG',
     #     'Accept': '*/*',
@@ -236,9 +236,9 @@ def upload_csv(args):
     # data = {
     #     f"""$------WebKitFormBoundary0W2raMzzSKutrSDG\\r\\nContent-Disposition: form-data; name': '"file"; filename={file_name}\\r\\nContent-Type: text/csv\\r\\n\\r\\n\\r\\n------WebKitFormBoundary0W2raMzzSKutrSDG--\\r\\n"""
     # }
-    file_name = os.path.basename(args.file_name)
+    file_name = os.path.basename(file_name)
     multipart_form_data = {
-        'file': (file_name, open(args.file_name, 'rb')),
+        'file': (file_name, open(file_name, 'rb')),
         'action': (None, 'store'),
         'path': (None, '/path1')
     }
@@ -247,7 +247,7 @@ def upload_csv(args):
     headers = {}
     r = make_request(url, files=multipart_form_data, headers=headers)
     generic_file_id = int(r.json()['data']['id'])
-    r = make_request(f'/projects/{args.project_id}')
+    r = make_request(f'/projects/{project_id}')
     dataset_id = r.json()['data']['attributes']['datasetId']
     headers={'content-type': 'application/vnd.api+json', 'accept':'application/vnd.api+json'}
 
@@ -266,7 +266,7 @@ def upload_csv(args):
             }
         }
     }
-    if args.tag:
+    if tag:
         post_data['data']['attributes']['tag_name'] = args.tag
     r = make_request('/source_files', headers=headers, json=post_data)
 
